@@ -13,14 +13,16 @@ except ImportError:
     # py2
     from ConfigParser import ConfigParser  # noqa: F401
 
-from tempfile import mkdtemp, NamedTemporaryFile, mktemp
+from tempfile import mkdtemp, NamedTemporaryFile
 import shutil
 import stat
+import uuid
 
 if sys.platform != "win32":
     import send2trash.plat_other
     from send2trash.plat_other import send2trash as s2t
 
+    INFO_SUFFIX = send2trash.plat_other.INFO_SUFFIX.decode()
     HOMETRASH = send2trash.plat_other.HOMETRASH
 else:
     pytest.skip("Skipping non-windows tests", allow_module_level=True)
@@ -28,9 +30,7 @@ else:
 
 @pytest.fixture
 def testfile():
-    file = NamedTemporaryFile(
-        dir=op.expanduser("~"), prefix="send2trash_test", delete=False
-    )
+    file = NamedTemporaryFile(dir=op.expanduser("~"), prefix="send2trash_test", delete=False)
     file.close()
     assert op.exists(file.name) is True
     yield file
@@ -40,7 +40,7 @@ def testfile():
         # Remove trash files if they exist
         if op.exists(op.join(HOMETRASH, "files", name)):
             os.remove(op.join(HOMETRASH, "files", name))
-            os.remove(op.join(HOMETRASH, "info", name + ".trashinfo"))
+            os.remove(op.join(HOMETRASH, "info", name + INFO_SUFFIX))
     if op.exists(file.name):
         os.remove(file.name)
 
@@ -62,10 +62,7 @@ def testfiles():
     yield files
     filenames = [op.basename(file.name) for file in files]
     [os.remove(op.join(HOMETRASH, "files", filename)) for filename in filenames]
-    [
-        os.remove(op.join(HOMETRASH, "info", filename + ".trashinfo"))
-        for filename in filenames
-    ]
+    [os.remove(op.join(HOMETRASH, "info", filename + INFO_SUFFIX)) for filename in filenames]
 
 
 def test_trash(testfile):
@@ -91,54 +88,52 @@ def _filesys_enc():
 
 
 @pytest.fixture
-def testUnicodefile():
+def gen_unicode_file():
     name = u"send2trash_tést1"
     file = op.join(op.expanduser(b"~"), name.encode("utf-8"))
     touch(file)
     assert op.exists(file) is True
     yield file
     # Cleanup trash files on supported platforms
-    if sys.platform != "win32":
-        # Remove trash files if they exist
-        if op.exists(op.join(HOMETRASH, "files", name)):
-            os.remove(op.join(HOMETRASH, "files", name))
-            os.remove(op.join(HOMETRASH, "info", name + ".trashinfo"))
+    if sys.platform != "win32" and op.exists(op.join(HOMETRASH, "files", name)):
+        os.remove(op.join(HOMETRASH, "files", name))
+        os.remove(op.join(HOMETRASH, "info", name + INFO_SUFFIX))
     if op.exists(file):
         os.remove(file)
 
 
 @pytest.mark.skipif(_filesys_enc() == "ascii", reason="Requires Unicode filesystem")
-def test_trash_bytes(testUnicodefile):
-    s2t(testUnicodefile)
-    assert not op.exists(testUnicodefile)
+def test_trash_bytes(gen_unicode_file):
+    s2t(gen_unicode_file)
+    assert not op.exists(gen_unicode_file)
 
 
 @pytest.mark.skipif(_filesys_enc() == "ascii", reason="Requires Unicode filesystem")
-def test_trash_unicode(testUnicodefile):
-    s2t(testUnicodefile.decode(sys.getfilesystemencoding()))
-    assert not op.exists(testUnicodefile)
+def test_trash_unicode(gen_unicode_file):
+    s2t(gen_unicode_file.decode(sys.getfilesystemencoding()))
+    assert not op.exists(gen_unicode_file)
 
 
 class ExtVol:
     def __init__(self, path):
-        self.trashTopdir = path
+        self.trash_topdir = path
         if PY3:
-            self.trashTopdir_b = os.fsencode(self.trashTopdir)
+            self.trash_topdir_b = os.fsencode(self.trash_topdir)
         else:
-            self.trashTopdir_b = self.trashTopdir
+            self.trash_topdir_b = self.trash_topdir
 
         def s_getdev(path):
             from send2trash.plat_other import is_parent
 
             st = os.lstat(path)
-            if is_parent(self.trashTopdir, path):
+            if is_parent(self.trash_topdir, path):
                 return "dev"
             return st.st_dev
 
         def s_ismount(path):
             if op.realpath(path) in (
-                op.realpath(self.trashTopdir),
-                op.realpath(self.trashTopdir_b),
+                op.realpath(self.trash_topdir),
+                op.realpath(self.trash_topdir_b),
             ):
                 return True
             return old_ismount(path)
@@ -151,85 +146,86 @@ class ExtVol:
     def cleanup(self):
         send2trash.plat_other.get_dev = self.old_getdev
         send2trash.plat_other.os.path.ismount = self.old_ismount
-        shutil.rmtree(self.trashTopdir)
+        shutil.rmtree(self.trash_topdir)
 
 
 @pytest.fixture
-def testExtVol():
-    trashTopdir = mkdtemp(prefix="s2t")
-    volume = ExtVol(trashTopdir)
-    fileName = "test.txt"
-    filePath = op.join(volume.trashTopdir, fileName)
-    touch(filePath)
-    assert op.exists(filePath) is True
-    yield volume, fileName, filePath
+def gen_ext_vol():
+    trash_topdir = mkdtemp(prefix="s2t")
+    volume = ExtVol(trash_topdir)
+    file_name = "test.txt"
+    file_path = op.join(volume.trash_topdir, file_name)
+    touch(file_path)
+    assert op.exists(file_path) is True
+    yield volume, file_name, file_path
     volume.cleanup()
 
 
-def test_trash_topdir(testExtVol):
-    trashDir = op.join(testExtVol[0].trashTopdir, ".Trash")
-    os.mkdir(trashDir, 0o777 | stat.S_ISVTX)
+def test_trash_topdir(gen_ext_vol):
+    trash_dir = op.join(gen_ext_vol[0].trash_topdir, ".Trash")
+    os.mkdir(trash_dir, 0o777 | stat.S_ISVTX)
 
-    s2t(testExtVol[2])
-    assert op.exists(testExtVol[2]) is False
-    assert (
-        op.exists(op.join(trashDir, str(os.getuid()), "files", testExtVol[1])) is True
-    )
+    s2t(gen_ext_vol[2])
+    assert op.exists(gen_ext_vol[2]) is False
+    assert op.exists(op.join(trash_dir, str(os.getuid()), "files", gen_ext_vol[1])) is True
     assert (
         op.exists(
-            op.join(trashDir, str(os.getuid()), "info", testExtVol[1] + ".trashinfo",)
+            op.join(
+                trash_dir,
+                str(os.getuid()),
+                "info",
+                gen_ext_vol[1] + INFO_SUFFIX,
+            )
         )
         is True
     )
     # info relative path (if another test is added, with the same fileName/Path,
     # then it gets renamed etc.)
     cfg = ConfigParser()
-    cfg.read(op.join(trashDir, str(os.getuid()), "info", testExtVol[1] + ".trashinfo"))
-    assert (testExtVol[1] == cfg.get("Trash Info", "Path", raw=True)) is True
+    cfg.read(op.join(trash_dir, str(os.getuid()), "info", gen_ext_vol[1] + INFO_SUFFIX))
+    assert (gen_ext_vol[1] == cfg.get("Trash Info", "Path", raw=True)) is True
 
 
-def test_trash_topdir_fallback(testExtVol):
-    s2t(testExtVol[2])
-    assert op.exists(testExtVol[2]) is False
+def test_trash_topdir_fallback(gen_ext_vol):
+    s2t(gen_ext_vol[2])
+    assert op.exists(gen_ext_vol[2]) is False
     assert (
         op.exists(
             op.join(
-                testExtVol[0].trashTopdir,
+                gen_ext_vol[0].trash_topdir,
                 ".Trash-" + str(os.getuid()),
                 "files",
-                testExtVol[1],
+                gen_ext_vol[1],
             )
         )
         is True
     )
 
 
-def test_trash_topdir_failure(testExtVol):
-    os.chmod(testExtVol[0].trashTopdir, 0o500)  # not writable to induce the exception
-    pytest.raises(TrashPermissionError, s2t, [testExtVol[2]])
-    os.chmod(testExtVol[0].trashTopdir, 0o700)  # writable to allow deletion
+def test_trash_topdir_failure(gen_ext_vol):
+    os.chmod(gen_ext_vol[0].trash_topdir, 0o500)  # not writable to induce the exception
+    pytest.raises(TrashPermissionError, s2t, [gen_ext_vol[2]])
+    os.chmod(gen_ext_vol[0].trash_topdir, 0o700)  # writable to allow deletion
 
 
-def test_trash_symlink(testExtVol):
-    # Use mktemp (race conditioney but no symlink equivalent)
-    # Since is_parent uses realpath(), and our getdev uses is_parent,
-    # this should work
-    slDir = mktemp(prefix="s2t", dir=op.expanduser("~"))
-    os.mkdir(op.join(testExtVol[0].trashTopdir, "subdir"), 0o700)
-    filePath = op.join(testExtVol[0].trashTopdir, "subdir", testExtVol[1])
-    touch(filePath)
-    os.symlink(op.join(testExtVol[0].trashTopdir, "subdir"), slDir)
-    s2t(op.join(slDir, testExtVol[1]))
-    assert op.exists(filePath) is False
+def test_trash_symlink(gen_ext_vol):
+    # Generating a random uuid named path for symlink
+    sl_dir = op.join(op.expanduser("~"), "s2t_" + str(uuid.uuid4()))
+    os.mkdir(op.join(gen_ext_vol[0].trash_topdir, "subdir"), 0o700)
+    file_path = op.join(gen_ext_vol[0].trash_topdir, "subdir", gen_ext_vol[1])
+    touch(file_path)
+    os.symlink(op.join(gen_ext_vol[0].trash_topdir, "subdir"), sl_dir)
+    s2t(op.join(sl_dir, gen_ext_vol[1]))
+    assert op.exists(file_path) is False
     assert (
         op.exists(
             op.join(
-                testExtVol[0].trashTopdir,
+                gen_ext_vol[0].trash_topdir,
                 ".Trash-" + str(os.getuid()),
                 "files",
-                testExtVol[1],
+                gen_ext_vol[1],
             )
         )
         is True
     )
-    os.remove(slDir)
+    os.remove(sl_dir)
